@@ -266,6 +266,47 @@ AccessibleText_getAttributes (AccessibleText *obj,
   return retval;
 }
 
+/**
+ * AccessibleText_getDefaultAttributes:
+ * @obj: a pointer to the #AccessibleText object to query.
+ *
+ * Get the default attributes applied to an #AccessibleText
+ *          object.
+ *          The text attributes correspond to CSS attributes where possible,
+ *          keys and values are delimited from one another via ":", and
+ *          the delimiter between key/value pairs is ";". Thus 
+ *          "font-size:10;foreground-color:0,0,0" would be a valid
+ *          return string.  The combination of this attribute set and
+ *          the attributes reported by #AccessibleText_getAttributes
+ *          describes the entire set of text attributes over a range.
+ *
+ * @Since: AT-SPI 1.4
+ *
+ * Returns: a text string describing the default attributes 
+ *          applied to a text object, (exclusive of explicitly-set
+ *          attributes), encoded as UTF-8.
+ **/
+char *
+AccessibleText_getDefaultAttributes (AccessibleText *obj)
+{
+  char *retval;	
+
+  if (obj == NULL)
+    {
+      return NULL;
+    }
+
+  retval = Accessibility_Text_getDefaultAttributes (CSPI_OBJREF (obj),
+						    cspi_ev ());
+
+  if (!cspi_check_ev ("getAttributes"))
+    {
+      retval = NULL;
+    }
+
+  return retval;
+}
+
 /**
  * AccessibleText_setCaretOffset:
  * @obj: a pointer to the #AccessibleText object on which to operate.
@@ -604,6 +645,7 @@ AccessibleText_getOffsetAtPoint (AccessibleText *obj,
  *
  * Get the bounding box for text within a range in an  #AccessibleText object.
  *
+ * @Since: AT-SPI 1.2
  **/
 void
 AccessibleText_getRangeExtents (AccessibleText *obj,
@@ -664,6 +706,8 @@ AccessibleText_getRangeExtents (AccessibleText *obj,
  * Get the ranges of text from an #AccessibleText object which lie within the
  *          bounds defined by (@x, @y) and (@x+@width, @y+@height).  
  *
+ * @Since: AT-SPI 1.2
+ *
  * Returns: a null-terminated list of pointers to AccessibleTextRange structs 
  *          detailing the bounded text.
  **/
@@ -701,6 +745,8 @@ AccessibleText_getBoundedRanges (AccessibleText *obj,
  * Free the memory used by a list of AccessibleTextRange structs.
  * The argument passed in should be an array of pointers 
  * AccessibleTextRange structs.  
+ *
+ * @Since: AT-SPI 1.2
  **/
 void
 AccessibleTextRange_freeRanges (AccessibleTextRange **ranges)
