@@ -164,7 +164,7 @@ spi_application_toolkit_event_listener (GSignalInvocationHint *signal_hint,
   spi_init_any_nil (&e.any_data, 
 		    spi_accessible_new_return (atk_get_root (), FALSE, NULL),
 		    Accessibility_ROLE_UNKNOWN,
-		    CORBA_string_dup (""));
+		    "");
   notify_listeners (the_app->toolkit_listeners, source, &e);
 
   bonobo_object_unref (BONOBO_OBJECT (source));
